# Deriver

Documentation in progress. See `contrib.examples.basic_usage_example.py` for a basic usage example.

# Requirements
Requires `selfies` and `rdkit` to be installed.

# Installation
rdkit can be installed on Ubuntu 18.04 using the provided script: 

https://github.com/cyclica/rdkit-installer

Source that environment once created, then you may install deriver using pip: `pip install deriver`, or by cloning this 
repo and from the cloned directory running: `pip install -e .`

# To-do:
* implement a random SELIFES generator method
* create a molecule object that can be passed around